#!/bin/bash

# 检查输入参数
if [ "$#" -ne 4 ]; then
    echo "Usage: $0 BACKUP_SPACE BACKUP_DIR EXCLUDE_DIR [backup|restore]"
    exit 1
fi

# 获取输入参数
BACKUP_SPACE=$1
BACKUP_DIR=$2
EXCLUDE_DIR=$3
ACTION=$4

# 检查目标目录是否存在
if [ ! -d "$BACKUP_DIR" ]; then
    echo "Backup directory $BACKUP_DIR does not exist."
    exit 1
fi

# 备份功能
if [ "$ACTION" == "backup" ]; then

    # 检查目标目录的可用空间
    AVAILABLE_SPACE=$(df -k --output=avail "$BACKUP_DIR" | tail -n1)
    if [ "$AVAILABLE_SPACE" -lt "$BACKUP_SPACE" ]; then
        echo "Not enough space in $BACKUP_DIR. Required: $BACKUP_SPACE KB, Available: $AVAILABLE_SPACE KB."
        exit 1
    fi

    echo "Starting backup..."
    rsync -aAXHv --exclude='/dev' --exclude='/proc' --exclude='/sys' --exclude='/tmp' --exclude='/run' --exclude='/lost+found' --exclude="$EXCLUDE_DIR" / "$BACKUP_DIR"
    echo "Backup completed."

# 恢复功能
elif [ "$ACTION" == "restore" ]; then
    echo "Starting restore..."
    rsync -aAXHv --exclude='/dev' --exclude='/proc' --exclude='/sys' --exclude='/tmp' --exclude='/run' --exclude='/lost+found' --exclude="$EXCLUDE_DIR" "$BACKUP_DIR" /
    echo "Restore completed."

# 无效的操作
else
    echo "Invalid action: $ACTION. Use 'backup' or 'restore'."
    exit 1
fi
