#!/bin/bash

# 列出已加载的模块
loaded_modules=$(lsmod | awk '{print $1}' | tail -n +2)

# 检查每个模块的来源
for module in $loaded_modules; do
    modinfo_output=$(modinfo $module)
    filename=$(echo "$modinfo_output" | grep "^filename:" | awk '{print $2}')
    intree=$(echo "$modinfo_output" | grep "^intree:" | awk '{print $2}')
    
    if [ "$intree" != "Y" ]; then
        echo "Module: $module"
        echo "Filename: $filename"
        echo "Intree: $intree"
        echo "Source: Possibly user-installed"
        echo "-----------------------------"
    fi
done


# 使用软件包管理器检查模块文件的来源
echo "Checking module files with package manager..."

if command -v dpkg &> /dev/null; then
    find /lib/modules/$(uname -r)/ -type f -name "*.ko" -o -name "*.ko.xz" | while read -r module_file; do
        package=$(dpkg -S "$module_file" 2>/dev/null)
        if [ -z "$package" ]; then
            echo "Module file: $module_file"
            echo "Source: Possibly user-installed"
            echo "-----------------------------"
        fi
    done
fi

if command -v rpm &> /dev/null; then
    find /lib/modules/$(uname -r)/ -type f -name "*.ko" -o -name "*.ko.xz" | while read -r module_file; do
        package=$(rpm -qf "$module_file" 2>/dev/null)
        if [ -z "$package" ]; then
            echo "Module file: $module_file"
            echo "Source: Possibly user-installed"
            echo "-----------------------------"
        fi
    done
fi
